@@ -57,6 +57,7 @@ Console::~Console()
 
 }
 
+#include <QRect>
 void Console::printConfig()
 {
     if (!m_config) {
@@ -94,7 +95,7 @@ void Console::printConfig()
         qDebug() << "Pos: " << output->pos();
         qDebug() << "MMSize: " << output->sizeMm();
         if (output->currentMode()) {
-            qDebug() << "Size: " << output->currentMode()->size();
+            qDebug() << "Size: " << output->size();
         }
         if (output->clones().isEmpty()) {
             qDebug() << "Clones: " << "None";
